==> eslint-config-atomic-1.2.0.tgz: package/strict.js <==
module.exports = {
  // JS Files
  "root": true,
  "env": {
    "atomtest": true,
    "es6": true,
    "node": true,
    "browser": true,
    "jasmine": true
  },
  "globals": {
    "atom": "readonly",
    "measure": "readonly"
  },
  "parser": "babel-eslint",
  "parserOptions": {
    "ecmaFeatures": {
      "jsx": true
    },
    "ecmaVersion": 2018,
    "sourceType": "module"
  },
  "plugins": ["prettier"],
  "extends": ["prettier", "eslint:recommended", "plugin:react/recommended"],
  "ignorePatterns": ["node_modules/"],
  "overrides": [
    {
      // Bundled node version with atom has an old ESLint
      // TypeScript files
      "files": ["**/*.ts", "**/*.tsx"],
      "parser": "@typescript-eslint/parser",
      "plugins": ["prettier", "@typescript-eslint"],
      "extends": [
        "prettier",
        "prettier/@typescript-eslint",
        "eslint:recommended",
        "plugin:react/recommended",
        "plugin:@typescript-eslint/eslint-recommended",
        "plugin:@typescript-eslint/recommended"
      ],
      "rules": {
        "@typescript-eslint/explicit-function-return-type": "off",
        "@typescript-eslint/explicit-module-boundary-types": "off",
        "@typescript-eslint/camelcase": "off",
        "@typescript-eslint/no-use-before-define": "off",
        "@typescript-eslint/member-delimiter-style": "off"
      }
    },
    {
      // JSON files
      "files": ["*.json"],
      "plugins": ["json"],
      "extends": ["prettier", "plugin:json/recommended"],
      "rules": {
        "json/*": [
          "error",
          {
            "allowComments": true
          }
        ]
      }
    },
    {
      // CoffeeScript files
      "files": ["**/*.coffee"],
      "parser": "eslint-plugin-coffee",
      "plugins": ["coffee"],
      "extends": ["plugin:coffee/eslint-recommended"]
    },
    {
      // YAML files
      "files": ["*.yaml", "*.yml"],
      "plugins": ["yaml"],
      "extends": ["plugin:yaml/recommended"]
    }
  ]
}

==> eslint-config-atomic-1.3.0.tgz: package/strict.js <==
module.exports = {
  // JS Files
  "root": true,
  "env": {
    "atomtest": true,
    "es6": true,
    "node": true,
    "browser": true,
    "jasmine": true
  },
  "globals": {
    "atom": "readonly",
    "measure": "readonly"
  },
  "parser": "babel-eslint",
  "parserOptions": {
    "ecmaFeatures": {
      "jsx": true
    },
    "ecmaVersion": 2018,
    "sourceType": "module"
  },
  "plugins": ["prettier"],
  "extends": ["prettier", "eslint:recommended"],
  "ignorePatterns": ["node_modules/"],
  "overrides": [
    {
      // Bundled node version with atom has an old ESLint
      // TypeScript files
      "files": ["**/*.ts", "**/*.tsx"],
      "parser": "@typescript-eslint/parser",
      "plugins": ["prettier", "@typescript-eslint"],
      "extends": [
        "prettier",
        "prettier/@typescript-eslint",
        "eslint:recommended",
        "plugin:react/recommended",
        "plugin:@typescript-eslint/eslint-recommended",
        "plugin:@typescript-eslint/recommended"
      ],
      "rules": {
        "@typescript-eslint/explicit-function-return-type": "off",
        "@typescript-eslint/explicit-module-boundary-types": "off",
        "@typescript-eslint/camelcase": "off",
        "@typescript-eslint/no-use-before-define": "off",
        "@typescript-eslint/member-delimiter-style": "off"
      }
    },
    {
      // JSON files
      "files": ["*.json"],
      "plugins": ["json"],
      "extends": ["prettier", "plugin:json/recommended"],
      "rules": {
        "json/*": [
          "error",
          {
            "allowComments": true
          }
        ]
      }
    },
    {
      // CoffeeScript files
      "files": ["**/*.coffee"],
      "parser": "eslint-plugin-coffee",
      "plugins": ["coffee"],
      "extends": ["plugin:coffee/eslint-recommended"]
    },
    {
      // YAML files
      "files": ["*.yaml", "*.yml"],
      "plugins": ["yaml"],
      "extends": ["plugin:yaml/recommended"]
    }
  ]
}
